==> 0.3.1.tar.gz: lib/bloc/common_widgets/user_pipulaity_card.dart <==

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../../utils/colors.dart';
import '../../utils/hexColors.dart';
import '../../utils/text_styling.dart';

// ignore: must_be_immutable
class UserPopularityCard extends StatelessWidget {
  int? userId;
  String? userName;
  String? userType;
  String textOne;
  String textTwo;
  String textThree;
  String textFour;
  String textFive;
  String textSix;
  String textSeven;
  String textEight;
  int? ownerId;
  String? ownerType;
  Null Function()? callback;
  String? businessId;
  String? imageurl;

  UserPopularityCard(
      {Key? key,
      required this.textOne,
      required this.textTwo,
      required this.textThree,
      required this.textFour,
      required this.textFive,
      required this.textSix,
      required this.textSeven,
      required this.textEight,
      this.userId,
      this.ownerId,
      this.ownerType,
      this.userName,
      this.imageurl,
      this.businessId,
      required this.callback,
      this.userType})
      : super(key: key);
  late TextStyleElements styleElements;

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return Container(
      color: HexColor(AppColors.appColorWhite),
      child: Align(
          alignment: Alignment.centerLeft,
          child: userType == "business"
              ? Row(children: <Widget>[
                  Expanded(
                    child: GestureDetector(
                        onTap: () {
                          /* Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => CourseDetailPage(
                          id: null,

                          */ /* userType: "staff",*/ /*
                        ),
                      ));*/
                        },
                        child: GestureDetector(
                          behavior: HitTestBehavior.translucent,
                          child: Column(
                            children: <Widget>[
                              Container(
                                margin: EdgeInsets.all(2.h),
                                child: Text(
                                  textFive,
                                  overflow: TextOverflow.ellipsis,
                                  style: styleElements
                                      .subtitle2ThemeScalable(context)
                                      .copyWith(
                                          fontWeight: FontWeight.bold,
                                          color: HexColor(
                                              AppColors.appColorBlack85)),
                                  textAlign: TextAlign.left,
                                ),
                              ),
                              Container(
                                margin: EdgeInsets.only(
                                    bottom: 2.h, left: 2.h, right: 2.h),
                                child: Text(
                                  textOne,
                                  overflow: TextOverflow.ellipsis,
                                  style: styleElements
                                      .captionThemeScalable(context),
                                  textAlign: TextAlign.left,
                                ),
                              ),
                            ],
                          ),
                          onTap: () async {

                          },
                        )),
                  ),
                  Expanded(
                    child: GestureDetector(
                        behavior: HitTestBehavior.translucent,
                        onTap: () async {

                        },
                        child: Column(
                          children: <Widget>[
                            Container(
                              margin: EdgeInsets.all(2.h),
                              child: Text(
                                textSix,
                                overflow: TextOverflow.ellipsis,
                                style: styleElements
                                    .subtitle2ThemeScalable(context)
                                    .copyWith(
                                        fontWeight: FontWeight.bold,
                                        color: HexColor(
                                            AppColors.appColorBlack85)),
                                textAlign: TextAlign.left,
                              ),
                            ),
                            Container(
                              margin: EdgeInsets.only(
                                  bottom: 2.h, left: 2.h, right: 2.h),
                              child: Text(
                                textTwo,
                                overflow: TextOverflow.ellipsis,
                                style: styleElements
                                    .captionThemeScalable(context),
                                textAlign: TextAlign.left,
                              ),
                            ),
                          ],
                        )),
                  )
                ])
              : Row(children: <Widget>[
                  Expanded(
                    child: GestureDetector(
                        onTap: () {
                          /* Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => CourseDetailPage(
                          id: null,

                          */ /* userType: "staff",*/ /*
                        ),
                      ));*/
                        },
                        child: GestureDetector(
                          behavior: HitTestBehavior.translucent,
                          child: Column(
                            children: <Widget>[
                              Container(
                                margin: EdgeInsets.all(2.h),
                                child: Text(
                                  textFive,
                                  overflow: TextOverflow.ellipsis,
                                  style: styleElements
                                      .subtitle2ThemeScalable(context)
                                      .copyWith(
                                          fontWeight: FontWeight.bold,
                                          color: HexColor(
                                              AppColors.appColorBlack85)),
                                  textAlign: TextAlign.left,
                                ),
                              ),
                              Container(
                                margin: EdgeInsets.only(
                                    bottom: 2.h, left: 2.h, right: 2.h),
                                child: Text(
                                  textOne,
                                  overflow: TextOverflow.ellipsis,
                                  style: styleElements
                                      .captionThemeScalable(context),
                                  textAlign: TextAlign.left,
                                ),
                              ),
                            ],
                          ),
                          onTap: () async {

                          },
                        )),
                  ),
                  Expanded(
                    child: GestureDetector(
                        behavior: HitTestBehavior.translucent,
                        onTap: () async {

                        },
                        child: Column(
                          children: <Widget>[
                            Container(
                              margin: EdgeInsets.all(2.h),
                              child: Text(
                                textSix,
                                overflow: TextOverflow.ellipsis,
                                style: styleElements
                                    .subtitle2ThemeScalable(context)
                                    .copyWith(
                                        fontWeight: FontWeight.bold,
                                        color: HexColor(
                                            AppColors.appColorBlack85)),
                                textAlign: TextAlign.left,
                              ),
                            ),
                            Container(
                              margin: EdgeInsets.only(
                                  bottom: 2.h, left: 2.h, right: 2.h),
                              child: Text(
                                textTwo,
                                overflow: TextOverflow.ellipsis,
                                style: styleElements
                                    .captionThemeScalable(context),
                                textAlign: TextAlign.left,
                              ),
                            ),
                          ],
                        )),
                  ),
                  Expanded(
                    child: GestureDetector(
                      behavior: HitTestBehavior.translucent,
                      onTap: () {

                      },
                      child: Column(
                        children: <Widget>[
                          Container(
                            margin: EdgeInsets.all(2.h),
                            child: Text(
                              textSeven,
                              overflow: TextOverflow.ellipsis,
                              style: styleElements
                                  .subtitle2ThemeScalable(context)
                                  .copyWith(
                                      fontWeight: FontWeight.bold,
                                      color:
                                          HexColor(AppColors.appColorBlack85)),
                              textAlign: TextAlign.left,
                            ),
                          ),
                          Container(
                            margin: EdgeInsets.only(
                                bottom: 2.h, left: 2.h, right: 2.h),
                            child: Text(
                              textThree,
                              overflow: TextOverflow.ellipsis,
                              style:
                                  styleElements.captionThemeScalable(context),
                              textAlign: TextAlign.left,
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                  Expanded(
                      child: GestureDetector(
                    behavior: HitTestBehavior.translucent,
                    onTap: () {

                    },
                    child: Column(
                      children: <Widget>[
                        Container(
                          margin: EdgeInsets.all(2.h),
                          child: Text(
                            textEight,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements
                                .subtitle2ThemeScalable(context)
                                .copyWith(
                                    fontWeight: FontWeight.bold,
                                    color: HexColor(AppColors.appColorBlack85)),
                            textAlign: TextAlign.left,
                          ),
                        ),
                        Container(
                          margin: EdgeInsets.only(
                              bottom: 2.h, left: 2.h, right: 2.h),
                          child: Text(
                            textFour,
                            overflow: TextOverflow.ellipsis,
                            style:
                                styleElements.captionThemeScalable(context),
                            textAlign: TextAlign.left,
                          ),
                        ),
                      ],
                    ),
                  )),
                ])),
    );
  }

  void update(updateFollowers) {
    callback!();
  }
}

==> 0.4.1.tar.gz: lib/bloc/common_widgets/user_pipulaity_card.dart <==

import 'package:flutter/material.dart';

import '../../utils/colors.dart';
import '../../utils/hexColors.dart';
import '../../utils/text_styling.dart';

// ignore: must_be_immutable
class UserPopularityCard extends StatelessWidget {
  int? userId;
  String? userName;
  String? userType;
  String textOne;
  String textTwo;
  String textThree;
  String textFour;
  String textFive;
  String textSix;
  String textSeven;
  String textEight;
  int? ownerId;
  String? ownerType;
  Null Function()? callback;
  String? businessId;
  String? imageurl;

  UserPopularityCard(
      {Key? key,
      required this.textOne,
      required this.textTwo,
      required this.textThree,
      required this.textFour,
      required this.textFive,
      required this.textSix,
      required this.textSeven,
      required this.textEight,
      this.userId,
      this.ownerId,
      this.ownerType,
      this.userName,
      this.imageurl,
      this.businessId,
      required this.callback,
      this.userType})
      : super(key: key);
  late TextStyleElements styleElements;

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return Container(
      color: HexColor(AppColors.appColorWhite),
      child: Align(
          alignment: Alignment.centerLeft,
          child: userType == "business"
              ? Row(children: <Widget>[
                  Expanded(
                    child: GestureDetector(
                        onTap: () {
                          /* Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => CourseDetailPage(
                          id: null,

                          */ /* userType: "staff",*/ /*
                        ),
                      ));*/
                        },
                        child: GestureDetector(
                          behavior: HitTestBehavior.translucent,
                          child: Column(
                            children: <Widget>[
                              Container(
                                margin: EdgeInsets.all(2),
                                child: Text(
                                  textFive,
                                  overflow: TextOverflow.ellipsis,
                                  style: styleElements
                                      .subtitle2ThemeScalable(context)
                                      .copyWith(
                                          fontWeight: FontWeight.bold,
                                          color: HexColor(
                                              AppColors.appColorBlack85)),
                                  textAlign: TextAlign.left,
                                ),
                              ),
                              Container(
                                margin: EdgeInsets.only(
                                    bottom: 2, left: 2, right: 2),
                                child: Text(
                                  textOne,
                                  overflow: TextOverflow.ellipsis,
                                  style: styleElements
                                      .captionThemeScalable(context),
                                  textAlign: TextAlign.left,
                                ),
                              ),
                            ],
                          ),
                          onTap: () async {

                          },
                        )),
                  ),
                  Expanded(
                    child: GestureDetector(
                        behavior: HitTestBehavior.translucent,
                        onTap: () async {

                        },
                        child: Column(
                          children: <Widget>[
                            Container(
                              margin: EdgeInsets.all(2),
                              child: Text(
                                textSix,
                                overflow: TextOverflow.ellipsis,
                                style: styleElements
                                    .subtitle2ThemeScalable(context)
                                    .copyWith(
                                        fontWeight: FontWeight.bold,
                                        color: HexColor(
                                            AppColors.appColorBlack85)),
                                textAlign: TextAlign.left,
                              ),
                            ),
                            Container(
                              margin: EdgeInsets.only(
                                  bottom: 2, left: 2, right: 2),
                              child: Text(
                                textTwo,
                                overflow: TextOverflow.ellipsis,
                                style: styleElements
                                    .captionThemeScalable(context),
                                textAlign: TextAlign.left,
                              ),
                            ),
                          ],
                        )),
                  )
                ])
              : Row(children: <Widget>[
                  Expanded(
                    child: GestureDetector(
                        onTap: () {
                          /* Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => CourseDetailPage(
                          id: null,

                          */ /* userType: "staff",*/ /*
                        ),
                      ));*/
                        },
                        child: GestureDetector(
                          behavior: HitTestBehavior.translucent,
                          child: Column(
                            children: <Widget>[
                              Container(
                                margin: EdgeInsets.all(2),
                                child: Text(
                                  textFive,
                                  overflow: TextOverflow.ellipsis,
                                  style: styleElements
                                      .subtitle2ThemeScalable(context)
                                      .copyWith(
                                          fontWeight: FontWeight.bold,
                                          color: HexColor(
                                              AppColors.appColorBlack85)),
                                  textAlign: TextAlign.left,
                                ),
                              ),
                              Container(
                                margin: EdgeInsets.only(
                                    bottom: 2, left: 2, right: 2),
                                child: Text(
                                  textOne,
                                  overflow: TextOverflow.ellipsis,
                                  style: styleElements
                                      .captionThemeScalable(context),
                                  textAlign: TextAlign.left,
                                ),
                              ),
                            ],
                          ),
                          onTap: () async {

                          },
                        )),
                  ),
                  Expanded(
                    child: GestureDetector(
                        behavior: HitTestBehavior.translucent,
                        onTap: () async {

                        },
                        child: Column(
                          children: <Widget>[
                            Container(
                              margin: EdgeInsets.all(2),
                              child: Text(
                                textSix,
                                overflow: TextOverflow.ellipsis,
                                style: styleElements
                                    .subtitle2ThemeScalable(context)
                                    .copyWith(
                                        fontWeight: FontWeight.bold,
                                        color: HexColor(
                                            AppColors.appColorBlack85)),
                                textAlign: TextAlign.left,
                              ),
                            ),
                            Container(
                              margin: EdgeInsets.only(
                                  bottom: 2, left: 2, right: 2),
                              child: Text(
                                textTwo,
                                overflow: TextOverflow.ellipsis,
                                style: styleElements
                                    .captionThemeScalable(context),
                                textAlign: TextAlign.left,
                              ),
                            ),
                          ],
                        )),
                  ),
                  Expanded(
                    child: GestureDetector(
                      behavior: HitTestBehavior.translucent,
                      onTap: () {

                      },
                      child: Column(
                        children: <Widget>[
                          Container(
                            margin: EdgeInsets.all(2),
                            child: Text(
                              textSeven,
                              overflow: TextOverflow.ellipsis,
                              style: styleElements
                                  .subtitle2ThemeScalable(context)
                                  .copyWith(
                                      fontWeight: FontWeight.bold,
                                      color:
                                          HexColor(AppColors.appColorBlack85)),
                              textAlign: TextAlign.left,
                            ),
                          ),
                          Container(
                            margin: EdgeInsets.only(
                                bottom: 2, left: 2, right: 2),
                            child: Text(
                              textThree,
                              overflow: TextOverflow.ellipsis,
                              style:
                                  styleElements.captionThemeScalable(context),
                              textAlign: TextAlign.left,
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                  Expanded(
                      child: GestureDetector(
                    behavior: HitTestBehavior.translucent,
                    onTap: () {

                    },
                    child: Column(
                      children: <Widget>[
                        Container(
                          margin: EdgeInsets.all(2),
                          child: Text(
                            textEight,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements
                                .subtitle2ThemeScalable(context)
                                .copyWith(
                                    fontWeight: FontWeight.bold,
                                    color: HexColor(AppColors.appColorBlack85)),
                            textAlign: TextAlign.left,
                          ),
                        ),
                        Container(
                          margin: EdgeInsets.only(
                              bottom: 2, left: 2, right: 2),
                          child: Text(
                            textFour,
                            overflow: TextOverflow.ellipsis,
                            style:
                                styleElements.captionThemeScalable(context),
                            textAlign: TextAlign.left,
                          ),
                        ),
                      ],
                    ),
                  )),
                ])),
    );
  }

  void update(updateFollowers) {
    callback!();
  }
}
